@@ -1,14 +1,19 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <winsock2.h>
+#include <ws2tcpip.h>
+
 extern "C" {
+#include <afsconfig.h>
 #include <afs/param.h>
+#include <roken.h>
 #include <afs/stds.h>
 }
 
@@ -32,7 +37,7 @@ extern "C" {
 
 void Shortcut_Init (void)
 {
-   CoInitialize(0);
+   CoInitializeEx(NULL, COINIT_APARTMENTTHREADED | COINIT_DISABLE_OLE1DDE);
 }
 
 
@@ -50,7 +55,7 @@ BOOL Shortcut_Create (LPTSTR pszTarget, LPCTSTR pszSource, LPTSTR pszDesc, LPTST
       IPersistFile *ppf;
       rc = psl->QueryInterface (IID_IPersistFile, (void **)&ppf);
       if (SUCCEEDED (rc))
-         { 
+         {
          rc = psl->SetPath (pszSource);
          if (SUCCEEDED (rc))
             {
@@ -76,7 +81,7 @@ BOOL Shortcut_Create (LPTSTR pszTarget, LPCTSTR pszSource, LPTSTR pszDesc, LPTST
       psl->Release ();
       }
    return SUCCEEDED(rc) ? TRUE : FALSE;
-} 
+}
 
 
 BOOL Shortcut_FixStartup (LPCTSTR pszLinkName, BOOL fAutoStart)
@@ -111,7 +116,7 @@ BOOL Shortcut_FixStartup (LPCTSTR pszLinkName, BOOL fAutoStart)
 
    if (fAutoStart)
    {
-       DWORD code, len, type; 
+       DWORD code, len, type;
        TCHAR szParams[ 64 ] = TEXT(AFSCREDS_SHORTCUT_OPTIONS);
 
        code = RegOpenKeyEx(HKEY_CURRENT_USER, AFSREG_USER_OPENAFS_SUBKEY,
