@@ -9,22 +9,15 @@
 
 #include <afsconfig.h>
 #include <afs/param.h>
-
-
 #include <afs/stds.h>
-#if defined(AFS_LINUX24_ENV)
-#define _REGEX_RE_COMP
+
+#include <roken.h>
+
+#ifdef HAVE_POSIX_REGEX		/* use POSIX regexp library */
+#include <regex.h>
 #endif
-#include <sys/types.h>
+
 #include <afs/cmd.h>
-#ifdef AFS_NT40_ENV
-#include <winsock2.h>
-#else
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <netdb.h>
-#endif
-#include <errno.h>
 #include <afs/com_err.h>
 #include <afs/afsutil.h>
 #include <afs/budb.h>
@@ -36,15 +29,11 @@
 #include <afs/vldbint.h>	/* PA */
 #include <afs/ktime.h>		/* PA */
 #include <ubik.h>
-#include <time.h>
 #include <lock.h>
-#include <afs/butc.h>
 #include <afs/tcdata.h>
 #include <afs/butx.h>
 #include <afs/vsutils_prototypes.h>
-#ifdef HAVE_POSIX_REGEX		/* use POSIX regexp library */
-#include <regex.h>
-#endif
+
 #include "bc.h"
 #include "error_macros.h"
 #include "bucoord_internal.h"
@@ -219,7 +208,6 @@ EvalVolumeSet2(struct bc_config *aconfig,
     *avols = (struct bc_volumeDump *)0;
     bulkentries.nbulkentries_len = 0;
     bulkentries.nbulkentries_val = 0;
-    memset(&attributes, 0, sizeof(attributes));
 
     /* For each of the volume set entries - collect the volumes that match it */
     for (tve = avs->ventries; tve; tve = tve->next) {
@@ -926,10 +914,11 @@ bc_WaitForNoJobs(void)
 {
     int i;
     int usefulJobRunning = 1;
-    int printWaiting = 1;
 
     extern dlqlinkT statusHead;
 
+    afs_com_err(whoami, 0, "waiting for job termination");
+
     while (usefulJobRunning) {
 	usefulJobRunning = (dlqEmpty(&statusHead) ? 0 : 1);
 	if (dispatchLock.excl_locked)
@@ -940,13 +929,8 @@ bc_WaitForNoJobs(void)
 	}
 
 	/* Wait 5 seconds and check again */
-	if (usefulJobRunning) {
-            if (printWaiting) {
-                afs_com_err(whoami, 0, "waiting for job termination");
-                printWaiting = 0;
-            }
+	if (usefulJobRunning)
 	    IOMGR_Sleep(5);
-        }
     }
     return (lastTaskCode);
 }
@@ -1648,7 +1632,6 @@ bc_DumpCmd(struct cmd_syndesc *as, void *arock)
     afs_int32 problemFindingDump;	/* can't find parent(s) */
 
     afs_int32 *portp = NULL;
-    afs_int32 portCount = 0;
     afs_int32 doAt, atTime;	/* Time a timed-dump is to start at */
     afs_int32 length;
     char *timeString;
@@ -1731,7 +1714,6 @@ bc_DumpCmd(struct cmd_syndesc *as, void *arock)
 
 	/* get the port number, if one was specified */
 	if (as->parms[2].items) {
-	    portCount = 1;
 	    portp = (afs_int32 *) malloc(sizeof(afs_int32));
 	    if (!portp) {
 		afs_com_err(whoami, BC_NOMEM, NULL);
@@ -2754,8 +2736,6 @@ DBLookupByVolume(char *volumeName)
     char vname[BU_MAXNAMELEN];
     char ds[50];
 
-    memset(volumeEntry, 0, sizeof(volumeEntry));
-
     for (pass = 0; pass < 2; pass++) {
 	/*p */
 	/* On second pass, search for backup volume */
