@@ -13,17 +13,9 @@
 
 #include <afsconfig.h>
 #include <afs/param.h>
-
-RCSID
-    ("$Header: /cvs/openafs/src/libadmin/cfg/cfgdb.c,v 1.6.14.2 2009/03/16 13:26:50 shadow Exp $");
-
 #include <afs/stds.h>
 
-#include <stddef.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
-#include <string.h>
+#include <roken.h>
 
 #include <pthread.h>
 
