@@ -14,42 +14,22 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
+#include <roken.h>
 
-#include <stdio.h>
-#include <sys/types.h>
-#include <errno.h>
-#include <string.h>
-#ifdef AFS_NT40_ENV
-#include <fcntl.h>
-#else
-#include <sys/file.h>
-#include <unistd.h>
-#include <sys/stat.h>
-#if defined(AFS_SUN5_ENV) || defined(AFS_NBSD_ENV)
-#include <sys/fcntl.h>
+#include <limits.h>
+
+#ifdef HAVE_SYS_RESOURCE_H
 #include <sys/resource.h>
 #endif
-#endif
 
 #include <rx/xdr.h>
 #include <afs/afsint.h>
-#include <errno.h>
 #include <afs/afssyscalls.h>
+#include <afs/afsutil.h>
+
 #include "nfs.h"
 #include "ihandle.h"
 #include "viceinode.h"
-#include "afs/afs_assert.h"
-#include <limits.h>
-
-#ifndef AFS_NT40_ENV
-#ifdef O_LARGEFILE
-#define afs_stat	stat64
-#define afs_fstat	fstat64
-#else /* !O_LARGEFILE */
-#define	afs_stat	stat
-#define	afs_fstat	fstat
-#endif /* !O_LARGEFILE */
-#endif /* AFS_NT40_ENV */
 
 #ifdef AFS_PTHREAD_ENV
 pthread_once_t ih_glock_once = PTHREAD_ONCE_INIT;
@@ -92,6 +72,7 @@ int fdInUseCount = 0;
 /* Hash table for inode handles */
 IHashBucket_t ihashTable[I_HANDLE_HASH_SIZE];
 
+static int _ih_release_r(IHandle_t * ihP);
 void *ih_sync_thread(void *);
 
 /* start-time configurable I/O limits */
@@ -478,13 +459,12 @@ fd_close(FdHandle_t * fdP)
     /* If this is not the only reference to the Inode then we can decrement
      * the reference count, otherwise we need to call ih_release.
      */
-    if (ihP->ih_refcnt > 1) {
+    if (ihP->ih_refcnt > 1)
 	ihP->ih_refcnt--;
-	IH_UNLOCK;
-    } else {
-	IH_UNLOCK;
-	ih_release(ihP);
-    }
+    else
+	_ih_release_r(ihP);
+
+    IH_UNLOCK;
 
     return 0;
 }
@@ -539,13 +519,12 @@ fd_reallyclose(FdHandle_t * fdP)
 
     /* If this is not the only reference to the Inode then we can decrement
      * the reference count, otherwise we need to call ih_release. */
-    if (ihP->ih_refcnt > 1) {
+    if (ihP->ih_refcnt > 1)
 	ihP->ih_refcnt--;
-	IH_UNLOCK;
-    } else {
-	IH_UNLOCK;
-	ih_release(ihP);
-    }
+    else
+	_ih_release_r(ihP);
+
+    IH_UNLOCK;
 
     return 0;
 }
@@ -902,33 +881,30 @@ ih_reallyclose(IHandle_t * ihP)
 
     ih_fdclose(ihP);
 
-    if (ihP->ih_refcnt > 1) {
+    if (ihP->ih_refcnt > 1)
 	ihP->ih_refcnt--;
-	IH_UNLOCK;
-    } else {
-	IH_UNLOCK;
-	ih_release(ihP);
-    }
+    else
+	_ih_release_r(ihP);
+
+    IH_UNLOCK;
     return 0;
 }
 
 /* Release an Inode handle. All cached file descriptors for this
  * inode are closed when the last reference to this handle is released
  */
-int
-ih_release(IHandle_t * ihP)
+static int
+_ih_release_r(IHandle_t * ihP)
 {
     int ihash;
 
     if (!ihP)
 	return 0;
 
-    IH_LOCK;
     osi_Assert(ihP->ih_refcnt > 0);
 
     if (ihP->ih_refcnt > 1) {
 	ihP->ih_refcnt--;
-	IH_UNLOCK;
 	return 0;
     }
 
@@ -942,10 +918,26 @@ ih_release(IHandle_t * ihP)
 
     DLL_INSERT_TAIL(ihP, ihAvailHead, ihAvailTail, ih_next, ih_prev);
 
-    IH_UNLOCK;
     return 0;
 }
 
+/* Release an Inode handle. All cached file descriptors for this
+ * inode are closed when the last reference to this handle is released
+ */
+int
+ih_release(IHandle_t * ihP)
+{
+    int ret;
+
+    if (!ihP)
+	return 0;
+
+    IH_LOCK;
+    ret = _ih_release_r(ihP);
+    IH_UNLOCK;
+    return ret;
+}
+
 /* Sync an inode to disk if its handle isn't NULL */
 int
 ih_condsync(IHandle_t * ihP)
@@ -981,15 +973,15 @@ ih_sync_all(void) {
 	for (; ihP; ihP = ihPnext) {
 
 	    if (ihP->ih_synced) {
-		FD_t fd;
+		FdHandle_t *fdP;
 
 		ihP->ih_synced = 0;
 		IH_UNLOCK;
 
-		fd = OS_IOPEN(ihP);
-		if (fd != INVALID_FD) {
-		    OS_SYNC(fd);
-		    OS_CLOSE(fd);
+		fdP = IH_OPEN(ihP);
+		if (fdP) {
+		    OS_SYNC(fdP->fd_fd);
+		    FDH_CLOSE(fdP);
 		}
 
 	  	IH_LOCK;
@@ -1001,14 +993,10 @@ ih_sync_all(void) {
 	    ihPnext = ihP->ih_next;
 	    if (ihPnext) ihPnext->ih_refcnt++;
 
-	    if (ihP->ih_refcnt > 1) {
+	    if (ihP->ih_refcnt > 1)
 		ihP->ih_refcnt--;
-	    } else {
-		IH_UNLOCK;
-		ih_release(ihP);
-		IH_LOCK;
-	    }
-
+	    else
+		_ih_release_r(ihP);
 	}
     }
     IH_UNLOCK;
@@ -1016,6 +1004,7 @@ ih_sync_all(void) {
 
 void *
 ih_sync_thread(void *dummy) {
+    afs_pthread_setname_self("ih_syncer");
     while(1) {
 
 #ifdef AFS_PTHREAD_ENV
@@ -1061,7 +1050,7 @@ ih_size(FD_t fd)
 	return -1;
     return size.QuadPart;
 #else
-    struct afs_stat status;
+    struct afs_stat_st status;
     if (afs_fstat(fd, &status) < 0)
 	return -1;
     return status.st_size;
